@@ -9,8 +9,7 @@ import random
 import numpy as np
 from scipy.stats import chi2
 
-
-def rglg(n, location = 0, scale = 1, shape=1):
+def rglg(n, location = 0, scale = 1, shape = 1):
     pQ = np.zeros(n)
     s_two = shape^2
     for i in range(0,n) :
@@ -20,4 +19,7 @@ def rglg(n, location = 0, scale = 1, shape=1):
     
     return pQ
 
-# print(rglg(n = 10))
\ No newline at end of file
+muestra = rglg(n = 10000)
+print(np.mean(muestra))
+print(np.median(muestra))
+print(np.var(muestra))
\ No newline at end of file
